@@ -44,6 +44,9 @@
 
 #include <cmath>
 
+#define SCROLL_MAX 621
+#define SCROLL_MIN 348
+
 TypeLabel::TypeLabel(QWidget *parent)
     : DFrame(parent)
 {
@@ -322,14 +325,14 @@ void CompressSettingPage::initUI()
     pRightLayout->setContentsMargins(0, 0, 50, 0);
 
     // 右侧滚动区域
-    QScrollArea *m_pRightScroll = new QScrollArea(this);
+    m_pRightScroll = new QScrollArea(this);
     DWidget *pRightWgt = new DWidget(this);
     pRightWgt->setLayout(pRightLayout);
     m_pRightScroll->setFrameShape(QFrame::NoFrame);
     m_pRightScroll->setWidgetResizable(true);
     m_pRightScroll->setMinimumHeight(100);           // task 16309调整最小大小
     m_pRightScroll->setWidget(pRightWgt);
-
+    m_pRightScroll->setFocusPolicy(Qt::NoFocus);
     // 按钮布局
     QHBoxLayout *pBtnLayout = new QHBoxLayout;
     pBtnLayout->addStretch(1);
@@ -357,6 +360,9 @@ void CompressSettingPage::initUI()
 
     setBackgroundRole(DPalette::Base);
     setAutoFillBackground(true);
+
+    // bug103712  滚动区域内widget高度发生变化导致页面闪动
+    pRightWgt ->setFixedHeight(pRightWgt->height());
 }
 
 void CompressSettingPage::initConnections()
@@ -657,6 +663,12 @@ void CompressSettingPage::slotRefreshFileNameEdit()
 
 void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
 {
+    // bug103712  滚动区域内widget高度发生变化导致页面闪动   页面变化前先设置widget大小
+    if (bEnabled) {
+        m_pRightScroll->widget()->setFixedHeight(SCROLL_MAX);
+    } else {
+        m_pRightScroll->widget()->setFixedHeight(SCROLL_MIN);
+    }
     // 设置控件是否隐藏
     m_pEncryptedLbl->setVisible(bEnabled);
     m_pPasswordEdt->setVisible(bEnabled);
@@ -679,6 +691,8 @@ void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
         m_pCpuCmb->setCurrentIndex(0);
         m_pCommentEdt->clear();
     }
+
+
 }
 
 void CompressSettingPage::slotSplitEdtEnabled()
